@@ -16,8 +16,7 @@
 #'   [global_prompt_install()].
 #'
 #' @export
-global_handle <- function(entrace = TRUE,
-                          prompt_install = TRUE) {
+global_handle <- function(entrace = TRUE, prompt_install = TRUE) {
   check_bool(entrace)
   check_bool(prompt_install)
 
@@ -61,8 +60,10 @@ hnd_prompt_install <- function(cnd) {
   }
 
   # Be defensive to avoid weird errors
-  if (!rlang::is_string(cnd$package) ||
-      is.null(findRestart("retry_loadNamespace"))) {
+  if (
+    !rlang::is_string(cnd$package) ||
+      is.null(findRestart("retry_loadNamespace"))
+  ) {
     return(rlang::zap())
   }
 
@@ -126,6 +127,16 @@ environment(hnd_prompt_install) <- baseenv()
 #' for the debuggability of your functions. See the comparison with
 #' `tryCatch()` section below.
 #'
+#' Another difference between `try_fetch()` and the base equivalent is
+#' that errors are matched across chains, see the `parent` argument of
+#' [abort()]. This is a useful property that makes `try_fetch()`
+#' insensitive to changes of implementation or context of evaluation
+#' that cause a classed error to suddenly get chained to a contextual
+#' error. Note that some chained conditions are not inherited, see the
+#' `.inherit` argument of [abort()] or [warn()]. In particular,
+#' downgraded conditions (e.g. from error to warning or from warning
+#' to message) are not matched across parents.
+#'
 #' @param expr An R expression.
 #' @param ... <[`dynamic-dots`][rlang::dyn-dots]> Named condition
 #'   handlers. The names specify the condition class for which a
@@ -166,9 +177,9 @@ environment(hnd_prompt_install) <- baseenv()
 #'
 #' `try_fetch()` generalises `tryCatch()` and `withCallingHandlers()`
 #' in a single function. It reproduces the behaviour of both calling
-#' and exiting handlers depending the on the return value of the
-#' handler. If the handler returns the [zap()] sentinel, it is taken
-#' as a calling handler that declines to recover from a condition.
+#' and exiting handlers depending on the return value of the handler.
+#' If the handler returns the [zap()] sentinel, it is taken as a
+#' calling handler that declines to recover from a condition.
 #' Otherwise, it is taken as an exiting handler which returns a value
 #' from the catching site.
 #'
@@ -199,9 +210,28 @@ handler_call <- quote(function(cnd) {
   {
     .__handler_frame__. <- TRUE
     .__setup_frame__. <- frame
+    if (inherits(cnd, "message")) {
+      except <- c("warning", "error")
+    } else if (inherits(cnd, "warning")) {
+      except <- "error"
+    } else {
+      except <- ""
+    }
+  }
+
+  while (!is_null(cnd)) {
+    if (inherits(cnd, CLASS)) {
+      out <- handlers[[I]](cnd)
+      if (!inherits(out, "rlang_zap")) throw(out)
+    }
+
+    inherit <- .subset2(.subset2(cnd, "rlang"), "inherit")
+    if (is_false(inherit)) {
+      return()
+    }
+
+    cnd <- .subset2(cnd, "parent")
   }
-  out <- handlers[[i]](cnd)
-  if (!inherits(out, "rlang_zap")) throw(out)
 })
 
 
@@ -305,7 +335,8 @@ catch_cnd <- function(expr, classes = "condition") {
 #' @keywords internal
 #' @export
 cnd_muffle <- function(cnd) {
-  restart <- switch(cnd_type(cnd),
+  restart <- switch(
+    cnd_type(cnd),
     message = "muffleMessage",
     warning = "muffleWarning",
     interrupt = "resume",
@@ -327,11 +358,20 @@ if (getRversion() < "4.0") {
 poke_global_handlers <- function(enable, ...) {
   check_bool(enable)
   handlers <- list2(...)
+  in_knitr <- knitr_in_progress()
 
-  if (enable) {
-    inject(globalCallingHandlers(!!!handlers))
+  if (in_knitr) {
+    if (enable) {
+      knitr::opts_chunk$set(calling.handlers = handlers)
+    } else {
+      abort("Can't remove calling handlers in knitted documents")
+    }
   } else {
-    inject(drop_global_handlers(!!!handlers))
+    if (enable) {
+      inject(globalCallingHandlers(!!!handlers))
+    } else {
+      inject(drop_global_handlers(!!!handlers))
+    }
   }
 }
 
