@@ -215,12 +215,14 @@ list3 <- function(...) {
 #' # There is no warning if the assignment is wrapped in braces.
 #' # This requires users to be explicit about their intent:
 #' my_list({ a <- 1 })
-dots_list <- function(...,
-                      .named = FALSE,
-                      .ignore_empty = c("trailing", "none", "all"),
-                      .preserve_empty = FALSE,
-                      .homonyms = c("keep", "first", "last", "error"),
-                      .check_assign = FALSE) {
+dots_list <- function(
+  ...,
+  .named = FALSE,
+  .ignore_empty = c("trailing", "none", "all"),
+  .preserve_empty = FALSE,
+  .homonyms = c("keep", "first", "last", "error"),
+  .check_assign = FALSE
+) {
   .Call(
     ffi_dots_list,
     frame_env = environment(),
@@ -233,12 +235,14 @@ dots_list <- function(...,
   )
 }
 
-dots_split <- function(...,
-                       .n_unnamed = NULL,
-                       .ignore_empty = c("trailing", "none", "all"),
-                       .preserve_empty = FALSE,
-                       .homonyms = c("keep", "first", "last", "error"),
-                       .check_assign = FALSE) {
+dots_split <- function(
+  ...,
+  .n_unnamed = NULL,
+  .ignore_empty = c("trailing", "none", "all"),
+  .preserve_empty = FALSE,
+  .homonyms = c("keep", "first", "last", "error"),
+  .check_assign = FALSE
+) {
   dots <- .Call(
     ffi_dots_list,
     frame_env = environment(),
@@ -279,6 +283,10 @@ dots_split <- function(...,
 #' Splice values at dots collection time
 #'
 #' @description
+#'
+#' `splice()` is an advanced feature of dynamic dots. It is rarely
+#' needed but can solve performance issues in edge cases.
+#'
 #' The splicing operator `!!!` operates both in values contexts like
 #' [list2()] and [dots_list()], and in metaprogramming contexts like
 #' [expr()], [enquos()], or [inject()]. While the end result looks the
@@ -314,6 +322,10 @@ dots_split <- function(...,
 #' inject(list2(1, splice(xs), 4))
 #' ```
 #'
+#' Note that `splice()` behaves differently than `!!!`. The splicing happens
+#' later and is processed by `list2()` or `dots_list()`. It does not work in any
+#' other tidyeval context than these list collectors.
+#'
 #' @param x A list or vector to splice non-eagerly.
 #' @export
 splice <- function(x) {
@@ -355,11 +367,13 @@ print.rlang_box_splice <- function(x, ...) {
 #'
 #' # Flatten the objects marked as spliced:
 #' flatten_if(dots, is_spliced)
-dots_values <- function(...,
-                        .ignore_empty = c("trailing", "none", "all"),
-                        .preserve_empty = FALSE,
-                        .homonyms = c("keep", "first", "last", "error"),
-                        .check_assign = FALSE) {
+dots_values <- function(
+  ...,
+  .ignore_empty = c("trailing", "none", "all"),
+  .preserve_empty = FALSE,
+  .homonyms = c("keep", "first", "last", "error"),
+  .check_assign = FALSE
+) {
   .External(
     ffi_dots_values,
     env = environment(),
