@@ -85,7 +85,7 @@ search_envs <- function() {
 #' @rdname search_envs
 #' @export
 search_env <- function(name) {
-  check_string(name)
+  check_name(name)
 
   if (!is_attached(name)) {
     abort(paste_line(
@@ -166,7 +166,8 @@ empty_env <- emptyenv
 #' @keywords internal
 #' @export
 ns_env <- function(x = caller_env()) {
-  env <- switch(typeof(x),
+  env <- switch(
+    typeof(x),
     builtin = ,
     special = ns_env("base"),
     closure = topenv(fn_env(x)),
@@ -175,7 +176,10 @@ ns_env <- function(x = caller_env()) {
   )
 
   if (!is_namespace(env)) {
-    stop_input_type(x, "a package name or a function inheriting from a namespace")
+    stop_input_type(
+      x,
+      "a package name or a function inheriting from a namespace"
+    )
   }
 
   env
@@ -186,15 +190,18 @@ ns_imports_env <- function(x = caller_env()) {
   env_parent(ns_env(x))
 }
 #' @rdname ns_env
-#' @param env A namespace environment.
 #' @export
 ns_env_name <- function(x = caller_env()) {
-  env <- switch(typeof(x),
+  env <- switch(
+    typeof(x),
     environment = ,
     builtin = ,
     special = ,
     closure = ns_env(x),
-    stop_input_type(x, "an environment or a function inheriting from a namespace")
+    stop_input_type(
+      x,
+      "an environment or a function inheriting from a namespace"
+    )
   )
   unname(getNamespaceName(env))
 }
@@ -203,7 +210,13 @@ ns_exports <- function(ns) getNamespaceExports(ns)
 ns_imports <- function(ns) getNamespaceImports(ns)
 
 ns_exports_has <- function(ns, name) {
-  if (is_reference(ns, base_ns_env)) {
+  if (is_string(ns)) {
+    if (!is_installed(ns)) {
+      return(FALSE)
+    }
+    ns <- ns_env(ns)
+  }
+  if (is_reference(ns, ns_env("base"))) {
     exports <- base_pkg_env
   } else {
     exports <- ns$.__NAMESPACE__.$exports
@@ -211,6 +224,11 @@ ns_exports_has <- function(ns, name) {
   !is_null(exports) && exists(name, envir = exports, inherits = FALSE)
 }
 
+ns_import_from <- function(ns, names, env = caller_env()) {
+  objs <- env_get_list(ns_env(ns), names)
+  env_bind(env, !!!objs)
+}
+
 #' Is an object a namespace environment?
 #'
 #' @param x An object to test.
@@ -231,7 +249,8 @@ env_type <- function(env) {
   }
 }
 friendly_env_type <- function(type) {
-  switch(type,
+  switch(
+    type,
     global = "the global environment",
     empty = "the empty environment",
     base = "the base environment",
@@ -323,8 +342,15 @@ env_label <- function(env) {
   }
 }
 
-# This does not behave like a normal environment because the parent is
-# NULL instead of the empty env
+#' Return the namespace registry env
+#'
+#' Note that the namespace registry does not behave like a normal
+#' environment because the parent is `NULL` instead of the empty
+#' environment. This is exported for expert usage in development tools
+#' only.
+#'
+#' @keywords internal
+#' @export
 ns_registry_env <- function() {
   .Call(ffi_ns_registry_env)
 }
