@@ -199,7 +199,7 @@ as_quosure <- function(x, env = NULL) {
 
   if (is_symbolic(x)) {
     if (is_null(env)) {
-      warn_deprecated(paste_line(
+      deprecate_warn(paste_line(
         "`as_quosure()` requires an explicit environment as of rlang 0.3.0.",
         "Please supply `env`."
       ))
@@ -242,10 +242,7 @@ new_quosures <- function(x) {
   if (!is_list(x) || !every(x, is_quosure)) {
     abort("Expected a list of quosures")
   }
-  structure(x,
-    class = c("quosures", "list"),
-    names = names2(x)
-  )
+  structure(x, class = c("quosures", "list"), names = names2(x))
 }
 #' @rdname new_quosures
 #' @export
@@ -272,7 +269,7 @@ c.quosures <- function(..., recursive = FALSE) {
   if (every(out, is_quosure)) {
     new_quosures(out)
   } else {
-    warn_deprecated(paste_line(
+    deprecate_warn(paste_line(
       "Quosure lists can't be concatenated with objects other than quosures as of rlang 0.3.0.",
       "Please call `as.list()` on the quosure list first."
     ))
@@ -309,7 +306,7 @@ as.list.quosures <- function(x, ...) {
   x
 }
 signal_quosure_assign <- function(x) {
-  warn_deprecated(paste_line(
+  deprecate_warn(paste_line(
     "Assigning non-quosure objects to quosure lists is deprecated as of rlang 0.3.0.",
     "Please coerce to a bare list beforehand with `as.list()`"
   ))
@@ -377,8 +374,7 @@ quo_squash <- function(quo, warn = FALSE) {
 #'
 #' @keywords internal
 #' @description
-#'
-#' `r lifecycle::badge("questioning")`
+#' `r lifecycle::badge("superseded")`
 #'
 #' **Note:** You should now use [as_label()] or [as_name()] instead
 #' of `quo_name()`. See life cycle section below.
@@ -405,7 +401,7 @@ quo_squash <- function(quo, warn = FALSE) {
 #'
 #' @section Life cycle:
 #'
-#' These functions are in the questioning life cycle stage.
+#' These functions are superseded.
 #'
 #' * [as_label()] and [as_name()] should be used instead of
 #'   `quo_name()`. `as_label()` transforms any R object to a string
@@ -453,37 +449,43 @@ quo_name <- function(quo) {
 }
 
 quo_squash_impl <- function(x, parent = NULL, warn = FALSE) {
+  quo_squash_do <- function(x) {
+    if (!is_false(warn)) {
+      if (is_string(warn)) {
+        msg <- warn
+      } else {
+        msg <- "Collapsing inner quosure"
+      }
+      warn(msg)
+      warn <- FALSE
+    }
+
+    while (is_quosure(maybe_missing(x))) {
+      x <- quo_get_expr(x)
+    }
+    if (!is_null(parent)) {
+      node_poke_car(parent, maybe_missing(x))
+    }
+    quo_squash_impl(x, parent, warn = warn)
+  }
+
+  node_squash <- function(x) {
+    while (!is_null(x)) {
+      quo_squash_impl(node_car(x), parent = x, warn = warn)
+      x <- node_cdr(x)
+    }
+  }
+
   switch_expr(
     x,
     language = {
       if (is_quosure(x)) {
-        if (!is_false(warn)) {
-          if (is_string(warn)) {
-            msg <- warn
-          } else {
-            msg <- "Collapsing inner quosure"
-          }
-          warn(msg)
-          warn <- FALSE
-        }
-
-        while (is_quosure(maybe_missing(x))) {
-          x <- quo_get_expr(x)
-        }
-        if (!is_null(parent)) {
-          node_poke_car(parent, maybe_missing(x))
-        }
-        quo_squash_impl(x, parent, warn = warn)
+        x <- quo_squash_do(x)
       } else {
-        quo_squash_impl(node_cdr(x), warn = warn)
+        node_squash(x)
       }
     },
-    pairlist = {
-      while (!is_null(x)) {
-        quo_squash_impl(node_car(x), x, warn = warn)
-        x <- node_cdr(x)
-      }
-    }
+    pairlist = node_squash(x)
   )
 
   maybe_missing(x)
@@ -492,14 +494,9 @@ quo_squash_impl <- function(x, parent = NULL, warn = FALSE) {
 
 #' @export
 print.quosure <- function(x, ...) {
-  cat_line(.trailing = FALSE,
-    style_bold("<quosure>"),
-    "expr: "
-  )
+  cat_line(.trailing = FALSE, style_bold("<quosure>"), "expr: ")
   quo_print(x)
-  cat_line(.trailing = FALSE,
-    "env:  "
-  )
+  cat_line(.trailing = FALSE, "env:  ")
 
   env <- quo_get_env(x)
   quo_env_print(env)
@@ -513,7 +510,7 @@ str.quosure <- function(object, ...) {
 
 #' @export
 as.character.quosure <- function(x, ...) {
-  warn_deprecated(paste_line(
+  deprecate_warn(paste_line(
     "Using `as.character()` on a quosure is deprecated as of rlang 0.3.0.",
     "Please use `as_label()` or `as_name()` instead."
   ))
@@ -522,7 +519,7 @@ as.character.quosure <- function(x, ...) {
 
 #' @export
 `[.quosure` <- function(x, i, ...) {
-  signal_soft_deprecated(c(
+  deprecate_soft(c(
     "Subsetting quosures with `[` is deprecated as of rlang 0.4.0",
     "Please use `quo_get_expr()` instead."
   ))
@@ -530,7 +527,7 @@ as.character.quosure <- function(x, ...) {
 }
 #' @export
 `[[.quosure` <- function(x, i, ...) {
-  signal_soft_deprecated(c(
+  deprecate_soft(c(
     "Subsetting quosures with `[[` is deprecated as of rlang 0.4.0",
     "Please use `quo_get_expr()` instead."
   ))
@@ -540,7 +537,10 @@ as.character.quosure <- function(x, ...) {
 # Create a circular list of colours. This infloops if printed in the REPL!
 new_quo_palette <- function() {
   last_node <- new_node(open_cyan, NULL)
-  palette <- new_node(open_blue, new_node(open_green, new_node(open_magenta, last_node)))
+  palette <- new_node(
+    open_blue,
+    new_node(open_green, new_node(open_magenta, last_node))
+  )
   node_poke_cdr(last_node, palette)
 
   # First node has no colour
@@ -569,16 +569,19 @@ quo_deparse <- function(x, lines = new_quo_deparser()) {
   lines$get_lines()
 }
 
-new_quo_deparser <- function(width = peek_option("width"),
-                             max_elements = 5L,
-                             crayon = has_ansi()) {
+new_quo_deparser <- function(
+  width = peek_option("width"),
+  max_elements = 5L,
+  crayon = has_ansi()
+) {
   lines <- new_lines(
     width = width,
     max_elements = max_elements,
     deparser = quo_deparse
   )
 
-  child_r6lite(lines,
+  child_r6lite(
+    lines,
     has_colour = crayon,
 
     quo_envs = list(),
@@ -732,3 +735,18 @@ median.quosure <- function(x, na.rm = TRUE, ...) {
 quantile.quosure <- function(x, na.rm = TRUE, ...) {
   abort_quosure_op("Summary", "quantile")
 }
+
+#' @export
+c.quosure <- function(..., recursive = FALSE) {
+  inputs <- list(...)
+  if (some(inputs, function(x) !is_quosure(x) && !is.list(x))) {
+    abort("Can't concatenate quosures with incompatible objects.")
+  }
+
+  out <- NextMethod()
+  if (!every(out, is_quosure)) {
+    abort("Can't concatenate quosures with incompatible objects.")
+  }
+
+  new_quosures(out)
+}
