@@ -27,7 +27,11 @@
   for (i in seq_along(vars)) {
     var <- vars[[i]]
     if (!is_symbol(var)) {
-      abort(paste0("Element ", i, " of the left-hand side of `%<-%` must be a symbol."))
+      abort(paste0(
+        "Element ",
+        i,
+        " of the left-hand side of `%<-%` must be a symbol."
+      ))
     }
 
     env[[as_string(var)]] <- value[[i]]
@@ -36,5 +40,4 @@
   invisible(value)
 }
 
-
 # nocov end
