@@ -1,10 +1,7 @@
 #ifndef RLANG_INTERNAL_INTERNAL_H
 #define RLANG_INTERNAL_INTERNAL_H
 
-#include "arg.h"
-#include "call.h"
-#include "quo.h"
-#include "vec.h"
+#include <rlang.h>
 
 struct rlang_globals_syms {
   r_obj* c_null;
@@ -55,7 +52,7 @@ extern struct rlang_globals_syms rlang_syms;
 
 // From cnd.c
 // Protects with the vmax stack
-const char* friendly_type_of(r_obj* x);
+const char* obj_type_friendly(r_obj* x);
 
 
 #endif
