@@ -1,8 +1,9 @@
 #include <rlang.h>
 #include <ctype.h>
-#include "internal.h"
+#include <stdlib.h>
 
 #include "decl/names-decl.h"
+#include "utils.h"
 
 // 3 leading '.' + 1 trailing '\0' + 24 characters
 #define MAX_IOTA_SIZE 28
@@ -223,6 +224,6 @@ void names_inform_repair(r_obj* old_names, r_obj* new_names) {
 }
 
 static
-void stop_large_name() {
+void stop_large_name(void) {
   r_abort("Can't tidy up name because it is too large.");
 }
