@@ -18,13 +18,15 @@ get_lang_strings <- function() {
 
 get_native_lang_string <- function() {
   lang_strings <- get_lang_strings()
-  if (length(lang_strings$same) == 0) testthat::skip("No native language string available")
+  if (length(lang_strings$same) == 0)
+    testthat::skip("No native language string available")
   lang_strings$same[[1L]]
 }
 
 get_alien_lang_string <- function() {
   lang_strings <- get_lang_strings()
-  if (length(lang_strings$different) == 0) testthat::skip("No alien language string available")
+  if (length(lang_strings$different) == 0)
+    testthat::skip("No alien language string available")
   lang_strings$different[[1L]]
 }
 
@@ -109,7 +111,7 @@ encodings <- function(bytes = FALSE) {
   out <- list(utf8 = utf8, unknown = unknown, latin1 = latin1)
 
   if (bytes) {
-    out <- list2(!!! out, bytes = encoding_bytes())
+    out <- list2(!!!out, bytes = encoding_bytes())
   }
 
   out
