@@ -17,10 +17,13 @@ test_that("chr_append() appends", {
 })
 
 test_that("r_warn() signals", {
-  expect_warning(regexp = "foo",
-    withCallingHandlers(warning = function(c) expect_null(c$call),
+  expect_warning(
+    regexp = "foo",
+    withCallingHandlers(
+      warning = function(c) expect_null(c$call),
       .Call(ffi_test_r_warn, "foo")
-    ))
+    )
+  )
 })
 
 test_that("r_on_exit() adds deferred expr", {
@@ -78,7 +81,7 @@ test_that("r_which_operator() returns correct tokens", {
   expect_identical(call_parse_type(""), "")
 
   expect_identical(call_parse_type(quote(?a)), "?unary")
-  expect_identical(call_parse_type(quote(a ? b)), "?")
+  expect_identical(call_parse_type(quote(a?b)), "?")
 
   expect_identical(call_parse_type(quote(while (a) b)), "while")
   expect_identical(call_parse_type(quote(for (a in b) b)), "for")
@@ -147,7 +150,7 @@ test_that("r_which_operator() returns correct tokens", {
 
   expect_identical(call_parse_type(quote(a * b)), "*")
   expect_identical(call_parse_type(quote(a / b)), "/")
-  expect_identical(call_parse_type(quote(a ^ b)), "^")
+  expect_identical(call_parse_type(quote(a^b)), "^")
   expect_identical(call_parse_type(quote(a$b)), "$")
   expect_identical(call_parse_type(quote(a@b)), "@")
   expect_identical(call_parse_type(quote(a[b])), "[")
@@ -165,7 +168,12 @@ test_that("r_which_operator() returns correct tokens", {
   expect_identical(call_parse_type(quote(`%%-`(a))), "")
 
   expect_identical(call_parse_type(quote((a))), "(")
-  expect_identical(call_parse_type(quote({ a })), "{")
+  expect_identical(
+    call_parse_type(quote({
+      a
+    })),
+    "{"
+  )
   expect_identical(call_parse_type(quote(`(-`(a))), "")
   expect_identical(call_parse_type(quote(`{-`(a))), "")
 })
@@ -175,7 +183,7 @@ test_that("client library passes tests", {
   return("Disabled")
 
   # Avoid installing into system library by default
-  skip_if(!nzchar(Sys.getenv("RLANG_FULL_TESTS")))
+  skip_if_not(nzchar(Sys.getenv("RLANG_FULL_TESTS")))
 
   skip_on_cran()
   skip_on_ci()
@@ -213,12 +221,12 @@ test_that("client library passes tests", {
   file.copy(src_path, temp_test_dir, overwrite = TRUE, recursive = TRUE)
   pkg_path <- file.path(temp_test_dir, "rlanglibtest")
 
-
   # We store the library as a zip to avoid VCS noise. Use
   # fixtures/Makefile to regenerate it.
   utils::unzip(zip_file, exdir = file.path(pkg_path, "src"))
 
-  install.packages(pkg_path,
+  install.packages(
+    pkg_path,
     repos = NULL,
     type = "source",
     lib = temp_lib,
@@ -227,7 +235,11 @@ test_that("client library passes tests", {
     quiet = TRUE
   )
 
-  result <- tools::testInstalledPackage("rlanglibtest", lib.loc = temp_lib, types = "test")
+  result <- tools::testInstalledPackage(
+    "rlanglibtest",
+    lib.loc = temp_lib,
+    types = "test"
+  )
   expect_identical(result, 0L)
 })
 
@@ -326,7 +338,6 @@ test_that("r_attrib_set() zaps several elements", {
   expect_true(is_reference(attrs1, node_cdr(attrs)))
   expect_true(is_reference(node_cdr(attrs1), node_cddr(attrs)))
 
-
   out2 <- c_set_attribute(x, "bar", NULL)
   attrs2 <- get_attributes(out2)
 
@@ -334,7 +345,6 @@ test_that("r_attrib_set() zaps several elements", {
   expect_false(is_reference(attrs2, attrs))
   expect_true(is_reference(node_cdr(attrs2), node_cddr(attrs)))
 
-
   out3 <- c_set_attribute(x, "baz", NULL)
   attrs3 <- get_attributes(out3)
 
@@ -357,7 +367,13 @@ test_that("can zap non-existing attributes", {
 })
 
 test_that("r_parse()", {
-  expect_equal(.Call(ffi_test_parse, "{ foo; bar }"), quote({ foo; bar }))
+  expect_equal(
+    .Call(ffi_test_parse, "{ foo; bar }"),
+    quote({
+      foo
+      bar
+    })
+  )
   expect_error(.Call(ffi_test_parse, "foo; bar"), "single expression")
   expect_error(.Call(ffi_test_parse, "foo\n bar"), "single expression")
 })
@@ -371,8 +387,9 @@ test_that("r_parse_eval()", {
 test_that("failed parses are printed if `rlang__verbose_errors` is non-NULL", {
   expect_error(
     expect_output(
-      regexp =  "foo; bar",
-      with_options(rlang__verbose_errors = TRUE,
+      regexp = "foo; bar",
+      with_options(
+        rlang__verbose_errors = TRUE,
         .Call(ffi_test_parse, "foo; bar")
       )
     ),
@@ -409,8 +426,14 @@ test_that("r_lgl_sum() handles NA", {
 test_that("r_lgl_which() handles NA", {
   expect_identical(r_lgl_which(lgl(TRUE, FALSE), TRUE), 1L)
   expect_identical(r_lgl_which(lgl(TRUE, FALSE), FALSE), 1L)
-  expect_identical(r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), TRUE), int(1L, NA, NA, 5L, NA))
-  expect_identical(r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), FALSE), int(1L, 5L))
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), TRUE),
+    int(1L, NA, NA, 5L, NA)
+  )
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), FALSE),
+    int(1L, 5L)
+  )
 })
 
 test_that("r_lgl_which() handles empty vectors", {
@@ -434,7 +457,10 @@ test_that("r_lgl_which() propagates names", {
 test_that("r_lgl_which() handles `NA` when propagation is disabled (#750)", {
   expect_identical(r_lgl_which(lgl(TRUE, FALSE, NA), FALSE), int(1))
   expect_identical(r_lgl_which(lgl(TRUE, FALSE, NA, TRUE), FALSE), int(1, 4))
-  expect_identical(r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, FALSE, TRUE), FALSE), int(1, 5, 7))
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, FALSE, TRUE), FALSE),
+    int(1, 5, 7)
+  )
 })
 
 test_that("r_pairlist_rev() reverses destructively", {
@@ -571,7 +597,6 @@ test_that("can put again after del", {
   expect_true(dict_put(dict, quote(foo), 2))
   expect_equal(dict_get(dict, quote(foo)), 2)
 
-
   # Used to fail because we deleted whole bucket instead of just a
   # node when this node appeared first in the bucket
 
@@ -733,9 +758,11 @@ test_that("can preserve and unpreserve repeatedly", {
   expect_false(dict_has(dict(), x))
 
   rlang_preserve(x)
-  on.exit(while (dict_has(dict(), x)) {
-    rlang_unpreserve(x)
-  })
+  on.exit(
+    while (dict_has(dict(), x)) {
+      rlang_unpreserve(x)
+    }
+  )
 
   expect_true(dict_has(dict(), x))
 
@@ -762,7 +789,10 @@ test_that("alloc_data_frame() creates data frame", {
   expect_equal(ncol(df), 3)
   expect_equal(class(df), "data.frame")
   expect_equal(names(df), c("a", "b", "c"))
-  expect_equal(lapply(df, typeof), list(a = "integer", b = "double", c = "character"))
+  expect_equal(
+    lapply(df, typeof),
+    list(a = "integer", b = "double", c = "character")
+  )
   expect_equal(lapply(df, length), list(a = 2, b = 2, c = 2))
 
   df <- alloc_data_frame(0L, chr(), int())
@@ -1109,7 +1139,7 @@ test_that("can push to dynamic list-of", {
 })
 
 test_that("internal error is thrown with OOB dyn-lof access", {
-  skip_if(!compiled_by_gcc())
+  skip_if_not(compiled_by_gcc())
   lof <- new_dyn_list_of("integer", 3, 2)
   expect_snapshot({
     err(lof_arr_push_back(lof, 0, 42L), "Location 0 does not exist")
@@ -1164,6 +1194,8 @@ test_that("can push to arrays in dynamic list-of", {
 })
 
 test_that("sexp iterator visits in full order", {
+  skip_if_not(has_private_accessors())
+
   it_dirs <- function(snapshot) {
     dirs <- sapply(snapshot, `[[`, "dir")
     dirs <- table(dirs)
@@ -1211,9 +1243,9 @@ test_that("re-encoding fails purposefully with any bytes", {
   bytes <- rawToChar(as.raw(0xdc))
   Encoding(bytes) <- "bytes"
 
-  expect_snapshot(
-    (expect_error(r_obj_encode_utf8(bytes)))
-  )
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
+    r_obj_encode_utf8(bytes)
+  })
 
   for (enc in test_encodings()) {
     expect_snapshot(
@@ -1332,7 +1364,10 @@ local({
 
 test_that("r_stop_internal() mentions expected namespace", {
   fn <- function() {
-    .Call(get("ffi_test_stop_internal", envir = asNamespace("rlang")), "Message.")
+    .Call(
+      get("ffi_test_stop_internal", envir = asNamespace("rlang")),
+      "Message."
+    )
   }
 
   environment(fn) <- ns_env("base")
