@@ -1,8 +1,11 @@
 test_that("format_error_bullets() formats bullets depending on names", {
-  expect_identical(format_error_bullets(c("foo", "bar")), "* foo\n* bar")
-  expect_identical(format_error_bullets(c(i = "foo", "*" = "baz", x = "bar", v = "bam")), "i foo\n* baz\nx bar\nv bam")
-  expect_error(format_error_bullets(c(i = "foo", u = "bar")))
-  expect_identical(format_error_bullets(chr()), chr())
+  expect_equal(format_error_bullets(c("foo", "bar")), "* foo\n* bar")
+  expect_equal(
+    format_error_bullets(c(i = "foo", "*" = "baz", x = "bar", v = "bam")),
+    "i foo\n* baz\nx bar\nv bam"
+  )
+  expect_equal(format_error_bullets(c(i = "foo", u = "bar")), "i foo\nbar")
+  expect_equal(format_error_bullets(chr()), chr())
 })
 
 test_that("default conditionMessage() method for rlang errors calls cnd_message()", {
@@ -64,9 +67,9 @@ test_that("can override header, body, and footer methods with fields", {
   expect_message(
     message(message_cnd(
       "rlang_foobar",
-      header = ~ "header",
-      body = ~ "body",
-      footer = ~ "footer"
+      header = ~"header",
+      body = ~"body",
+      footer = ~"footer"
     )),
     "header\nbody\nfooter",
     class = "rlang_foobar"
@@ -83,7 +86,11 @@ test_that("can override header, body, and footer methods with fields", {
   )
 
   expect_error(
-    stop(error_cnd("rlang_foobar", message = "header", body = ~ format_error_bullets("body"))),
+    stop(error_cnd(
+      "rlang_foobar",
+      message = "header",
+      body = ~ format_error_bullets("body")
+    )),
     "header\n* body",
     fixed = TRUE,
     class = "rlang_foobar"
@@ -179,13 +186,6 @@ test_that("cli is not used when message is escaped with `I()`", {
   )
 })
 
-test_that("cli syntax is escaped in 'try' mode", {
-  local_use_cli()
-
-  x <- "{foo {{}}"
-  expect_equal(rlang_format_message(x), x)
-})
-
 test_that(".rlang_cli_str_restore() deals with attributes", {
   msg <- structure("foo", attr = TRUE)
 
@@ -199,24 +199,6 @@ test_that(".rlang_cli_str_restore() deals with attributes", {
     .rlang_cli_str_restore("bar", msg_oo),
     "bar"
   )
-
-  local_use_cli(inline = TRUE, format = TRUE)
-  expect_equal(
-    attributes(rlang_format_message(msg)),
-    list(attr = TRUE)
-  )
-
-  local_use_cli(inline = FALSE, format = FALSE)
-  expect_equal(
-    attributes(rlang_format_message(msg)),
-    list(attr = TRUE)
-  )
-
-  local_use_cli(inline = FALSE, format = TRUE)
-  expect_equal(
-    attributes(rlang_format_message(msg)),
-    list(attr = TRUE)
-  )
 })
 
 skip_if_not_installed("cli", "2.5.0")
@@ -228,25 +210,29 @@ cli::test_that_cli("format_error_bullets() generates bullets", {
   })
 })
 
-cli::test_that_cli(configs = c("plain", "fancy"), "can use cli syntax in `cnd_message()` methods", {
-  local_methods(
-    cnd_header.rlang_foobar = function(cnd, ...) {
-      cli::format_inline("Header: {.emph {cnd$field}}")
-    },
-    cnd_body.rlang_foobar = function(cnd, ...) {
-      c("i" = cli::format_inline("Bullet: {.emph {cnd$field}}"))
-    },
-    cnd_footer.rlang_foobar = function(cnd, ...) {
-      c("_" = cli::format_inline("i" = "Footer: {.emph {cnd$field}}"))
-    }
-  )
-  cnd <- error_cnd(
-    "rlang_foobar",
-    field = "User { {field}.",
-    use_cli_format = TRUE
-  )
-  expect_snapshot(cnd_message(cnd))
-})
+cli::test_that_cli(
+  configs = c("plain", "fancy"),
+  "can use cli syntax in `cnd_message()` methods",
+  {
+    local_methods(
+      cnd_header.rlang_foobar = function(cnd, ...) {
+        cli::format_inline("Header: {.emph {cnd$field}}")
+      },
+      cnd_body.rlang_foobar = function(cnd, ...) {
+        c("i" = cli::format_inline("Bullet: {.emph {cnd$field}}"))
+      },
+      cnd_footer.rlang_foobar = function(cnd, ...) {
+        c("_" = cli::format_inline("i" = "Footer: {.emph {cnd$field}}"))
+      }
+    )
+    cnd <- error_cnd(
+      "rlang_foobar",
+      field = "User { {field}.",
+      use_cli_format = TRUE
+    )
+    expect_snapshot(cnd_message(cnd))
+  }
+)
 
 test_that("prefix takes call into account", {
   expect_snapshot({
@@ -274,10 +260,12 @@ test_that("long prefixes cause a line break", {
 test_that("prefixes include srcrefs", {
   withr::local_envvar("TESTTHAT" = "")
 
-  eval_parse("{
+  eval_parse(
+    "{
     f <- function() g()
     g <- function() abort('Foo.')
-  }")
+  }"
+  )
 
   src_file <- g %@% srcref %@% srcfile
   src_file$filename <- "/foo/bar/baz/myfile.R"
@@ -346,9 +334,9 @@ test_that("parent errors prints with bullets in all cases", {
     )
   }
 
-  expect_snapshot({
-    (expect_error(f(TRUE)))
-    (expect_error(f(FALSE)))
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
+    f(TRUE)
+    f(FALSE)
   })
 })
 
@@ -484,11 +472,28 @@ test_that("as.character() and conditionMessage() methods for errors, warnings, a
 })
 
 test_that("multiline operator calls are preserved", {
-  err <- function(expr) error_cnd(message = "This is the error message.", call = enexpr(expr))
+  err <- function(expr)
+    error_cnd(message = "This is the error message.", call = enexpr(expr))
 
-  expect_snapshot_output(err(1 + ("veeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeery_long" + "veeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeery_long")))
-  expect_snapshot_output(err({ 1; 2 } + { 2; 3 }))
-  expect_snapshot_output(err(x[{ 1; 2 }]))
+  expect_snapshot_output(err(
+    1 +
+      ("veeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeery_long" +
+        "veeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeery_long")
+  ))
+  expect_snapshot_output(err(
+    {
+      1
+      2
+    } +
+      {
+        2
+        3
+      }
+  ))
+  expect_snapshot_output(err(x[{
+    1
+    2
+  }]))
 })
 
 test_that("eval_tidy() is not mentioned in calls", {
@@ -514,10 +519,106 @@ test_that("can disable srcrefs in call formatting", {
   withr::local_envvar(c("TESTTHAT" = "false"))
   local_options(rlang_call_format_srcrefs = FALSE)
 
-  with_srcref("{
+  with_srcref(
+    "{
     f <- function() { g() }
     g <- function() abort('foo')
-  }")
+  }"
+  )
 
   expect_snapshot(err(f()))
 })
+
+test_that("fallback method supports unknown bullets (#1364)", {
+  local_use_cli(format = FALSE)
+  expect_snapshot({
+    "With fallback"
+    (expect_error(abort(c("foo", i2 = "bar"))))
+    (expect_error(abort(c(i1 = "foo", i2 = "bar"))))
+  })
+
+  local_use_cli(format = TRUE)
+  expect_snapshot({
+    "With cli"
+    (expect_error(abort(c("foo", i2 = "bar"))))
+    (expect_error(abort(c(i1 = "foo", i2 = "bar"))))
+  })
+})
+
+test_that("`cnd_message(prefix = TRUE)` propagates warning style across parent errors (#1387)", {
+  local_options(cli.num_colors = 8)
+
+  hnd_message <- function(cnd) cnd_message(cnd, prefix = TRUE)
+
+  msg_warning <- try_fetch(
+    error = function(cnd) warn("foo", parent = cnd),
+    condition = hnd_message,
+    abort("bar")
+  )
+  msg_error <- try_fetch(
+    error = function(cnd) abort("foo", parent = cnd),
+    condition = hnd_message,
+    abort("bar")
+  )
+
+  expect_false(grepl("\033\\[1mCaused by error", msg_warning))
+  expect_true(grepl("\033\\[1mCaused by error", msg_error))
+})
+
+test_that("arguments are highlighted but code spans are not", {
+  local_options("rlang:::trace_test_highlight" = TRUE)
+
+  err <- error_cnd(
+    header = function(cnd)
+      sprintf(
+        "%s - %s - %s",
+        format_arg("arg1"),
+        format_code("code"),
+        format_arg("arg2")
+      )
+  )
+
+  expect_snapshot({
+    with_error_arg_highlight(
+      print(err)
+    )
+  })
+})
+
+test_that("chained errors may have empty messages", {
+  parent <- error_cnd(message = "Tilt.")
+  child <- error_cnd(parent = parent)
+  expect_snapshot({
+    print(child)
+    cat_line(cnd_message(child, prefix = TRUE))
+  })
+
+  # This is the intended usage
+  child <- error_cnd(call = call("foo"), parent = parent)
+  expect_snapshot({
+    print(child)
+    cat_line(cnd_message(child, prefix = TRUE))
+  })
+
+  # Irrelevant calls are considered as NULL
+  child <- error_cnd(call = call("eval"), parent = parent)
+  expect_snapshot({
+    print(child)
+    cat_line(cnd_message(child, prefix = TRUE))
+  })
+})
+
+test_that("`cnd_message()` returns a single string", {
+  local_interactive(TRUE)
+
+  f <- function(do) g(do)
+  g <- function(do) h(do)
+  h <- function(do) do("foo")
+
+  cnd <- catch_cnd(f(abort))
+  cnd <- cnd_set_backtrace_on_error(cnd, "reminder")
+  expect_length(cnd_message(cnd), 1)
+
+  class(cnd) <- c("rlang_warning", "warning", "condition")
+  expect_length(cnd_message(cnd), 1)
+})
