@@ -12,21 +12,53 @@ test_that("line_push() trims trailing spaces", {
 })
 
 test_that("line_push() doesn't trim trailing spaces on sticky inputs", {
-  expect_identical(line_push("tag", " = ", sticky = TRUE, width = 3L, indent = 2L), "tag = ")
+  expect_identical(
+    line_push("tag", " = ", sticky = TRUE, width = 3L, indent = 2L),
+    "tag = "
+  )
 })
 
 test_that("sticky input sticks", {
-  expect_identical(line_push("foo  ", "bar", sticky = TRUE, width = 1L), "foo  bar")
+  expect_identical(
+    line_push("foo  ", "bar", sticky = TRUE, width = 1L),
+    "foo  bar"
+  )
 })
 
 test_that("line_push() respects boundaries", {
-  expect_identical(line_push("foo, ", "bar", boundary = 4L, width = 1L, indent = 2L), c("foo,", "  bar"))
-  expect_identical(line_push("foo, ", "bar", sticky = TRUE, boundary = 4L, width = 1L, indent = 2L), c("foo,", "  bar"))
-  expect_identical(line_push("foo, bar", "baz", boundary = 4L, width = 1L, indent = 2L), c("foo, bar", "  baz"))
+  expect_identical(
+    line_push("foo, ", "bar", boundary = 4L, width = 1L, indent = 2L),
+    c("foo,", "  bar")
+  )
+  expect_identical(
+    line_push(
+      "foo, ",
+      "bar",
+      sticky = TRUE,
+      boundary = 4L,
+      width = 1L,
+      indent = 2L
+    ),
+    c("foo,", "  bar")
+  )
+  expect_identical(
+    line_push("foo, bar", "baz", boundary = 4L, width = 1L, indent = 2L),
+    c("foo, bar", "  baz")
+  )
 })
 
 test_that("line_push() handles the nchar(line) == boundary case", {
-  expect_identical(line_push("  tag = ", "bar", sticky = TRUE, boundary = 8L, width = 3L, indent = 2L), "  tag = bar")
+  expect_identical(
+    line_push(
+      "  tag = ",
+      "bar",
+      sticky = TRUE,
+      boundary = 8L,
+      width = 3L,
+      indent = 2L
+    ),
+    "  tag = bar"
+  )
 })
 
 test_that("line_push() strips ANSI codes before computing overflow", {
@@ -35,7 +67,10 @@ test_that("line_push() strips ANSI codes before computing overflow", {
     skip("test needs cli")
   }
   expect_identical(length(line_push("foo", open_blue(), width = 3L)), 2L)
-  expect_identical(length(line_push("foo", open_blue(), width = 3L, has_colour = TRUE)), 1L)
+  expect_identical(
+    length(line_push("foo", open_blue(), width = 3L, has_colour = TRUE)),
+    1L
+  )
 })
 
 test_that("can push several lines (useful for default base deparser)", {
@@ -44,50 +79,144 @@ test_that("can push several lines (useful for default base deparser)", {
 
 test_that("control flow is deparsed", {
   expect_identical(fn_call_deparse(expr(function(a, b) 1)), "function(a, b) 1")
-  expect_identical(fn_call_deparse(expr(function(a = 1, b = 2) { 3; 4; 5 })), c("function(a = 1, b = 2) {", "  3", "  4", "  5", "}"))
-  expect_identical(while_deparse(quote(while(1) 2)), "while (1) 2")
-  expect_identical(for_deparse(quote(for(a in 2) 3)), "for (a in 2) 3")
+  expect_identical(
+    fn_call_deparse(expr(function(a = 1, b = 2) {
+      3
+      4
+      5
+    })),
+    c("function(a = 1, b = 2) {", "  3", "  4", "  5", "}")
+  )
+  expect_identical(while_deparse(quote(while (1) 2)), "while (1) 2")
+  expect_identical(for_deparse(quote(for (a in 2) 3)), "for (a in 2) 3")
   expect_identical(repeat_deparse(quote(repeat 1)), "repeat 1")
-  expect_identical(if_deparse(quote(if (1) 2 else { 3 })), c("if (1) 2 else {", "  3", "}"))
+  expect_identical(
+    if_deparse(quote(
+      if (1) 2 else {
+        3
+      }
+    )),
+    c("if (1) 2 else {", "  3", "}")
+  )
 })
 
 test_that("functions defs increase indent", {
   ctxt <- new_lines(width = 3L)
-  expect_identical(sexp_deparse(quote(function() 1), ctxt), c("function()", "  1"))
+  expect_identical(
+    sexp_deparse(quote(function() 1), ctxt),
+    c("function()", "  1")
+  )
 
   ctxt <- new_lines(width = 3L)
   expect_identical(sexp_deparse(function() 1, ctxt), c("<function()", "  1>"))
 })
 
 test_that("blocks are deparsed", {
-  expect_identical(braces_deparse(quote({1; 2; { 3; 4 }})), c("{", "  1", "  2", "  {", "    3", "    4", "  }", "}"))
-  expect_identical_(sexp_deparse(quote({{ 1 }})), c("{", "  {", "    1", "  }", "}"))
+  expect_identical(
+    braces_deparse(quote({
+      1
+      2
+      {
+        3
+        4
+      }
+    })),
+    c("{", "  1", "  2", "  {", "    3", "    4", "  }", "}")
+  )
+  expect_identical_(
+    sexp_deparse(quote({
+      {
+        1
+      }
+    })),
+    c("{", "  {", "    1", "  }", "}")
+  )
 
   ctxt <- new_lines(width = 3L)
-  expected_lines <- c("{", "  11111", "  22222", "  {", "    33333", "    44444", "  }", "}")
-  expect_identical(braces_deparse(quote({11111; 22222; { 33333; 44444 }}), ctxt), expected_lines)
+  expected_lines <- c(
+    "{",
+    "  11111",
+    "  22222",
+    "  {",
+    "    33333",
+    "    44444",
+    "  }",
+    "}"
+  )
+  expect_identical(
+    braces_deparse(
+      quote({
+        11111
+        22222
+        {
+          33333
+          44444
+        }
+      }),
+      ctxt
+    ),
+    expected_lines
+  )
 })
 
 test_that("multiple openers on the same line only trigger one indent", {
   ctxt <- new_lines(width = 3L)
-  expect_identical(sexp_deparse(quote(function() { 1 }), ctxt), c("function()", "  {", "    1", "  }"))
+  expect_identical(
+    sexp_deparse(
+      quote(function() {
+        1
+      }),
+      ctxt
+    ),
+    c("function()", "  {", "    1", "  }")
+  )
 
   ctxt <- new_lines(width = 12L)
-  expect_identical(sexp_deparse(quote(function() { 1 }), ctxt), c("function() {", "  1", "}"))
+  expect_identical(
+    sexp_deparse(
+      quote(function() {
+        1
+      }),
+      ctxt
+    ),
+    c("function() {", "  1", "}")
+  )
 })
 
 test_that("multiple openers on the same line are correctly reset", {
-  expect_identical(sexp_deparse(quote({ 1(2()) })), c("{", "  1(2())", "}"))
+  expect_identical(
+    sexp_deparse(quote({
+      1(2())
+    })),
+    c("{", "  1(2())", "}")
+  )
 })
 
 test_that("parentheses are deparsed", {
   expect_identical(parens_deparse(quote((1))), "(1)")
-  expect_identical(parens_deparse(quote(({ 1; 2 }))), c("({", "  1", "  2", "})"))
-  expect_identical(sexp_deparse(quote(({({ 1 })}))), c("({", "  ({", "    1", "  })", "})"))
+  expect_identical(
+    parens_deparse(quote(
+      ({
+        1
+        2
+      })
+    )),
+    c("({", "  1", "  2", "})")
+  )
+  expect_identical(
+    sexp_deparse(quote(
+      ({
+        ({
+          1
+        })
+      })
+    )),
+    c("({", "  ({", "    1", "  })", "})")
+  )
 })
 
 test_that("spaced operators are deparsed", {
-  expect_identical(spaced_op_deparse(quote(1 ? 2)), "1 ? 2")
+  expect_identical(spaced_op_deparse(quote(1?2)), "1 ? 2")
   expect_identical(spaced_op_deparse(quote(1 <- 2)), "1 <- 2")
   expect_identical(spaced_op_deparse(quote(1 <<- 2)), "1 <<- 2")
   expect_identical(spaced_op_deparse(quote(`=`(1, 2))), "1 = 2")
@@ -109,7 +238,19 @@ test_that("spaced operators are deparsed", {
   expect_identical(spaced_op_deparse(quote(1 / 2)), "1 / 2")
   expect_identical(spaced_op_deparse(quote(1 %% 2)), "1 %% 2")
   expect_identical(spaced_op_deparse(quote(1 %>% 2)), "1 %>% 2")
-  expect_identical(sexp_deparse(quote({ 1; 2 } + { 3; 4 })), c("{", "  1", "  2", "} + {", "  3", "  4", "}"))
+  expect_identical(
+    sexp_deparse(quote(
+      {
+        1
+        2
+      } +
+        {
+          3
+          4
+        }
+    )),
+    c("{", "  1", "  2", "} + {", "  3", "  4", "}")
+  )
 })
 
 test_that("unspaced operators are deparsed", {
@@ -127,8 +268,11 @@ test_that("operands are wrapped in parentheses to ensure correct predecence", {
 
   skip_on_cran()
   skip_if(getRversion() < "4.0.0")
-  expect_identical_(sexp_deparse(quote(function() 1 ? 2)), "(function() 1) ? 2")
-  expect_identical_(sexp_deparse(expr(!!quote(function() 1) ? 2)), "(function() 1) ? 2")
+  expect_identical_(sexp_deparse(quote(function() 1?2)), "(function() 1) ? 2")
+  expect_identical_(
+    sexp_deparse(expr(!!quote(function() 1)?2)),
+    "(function() 1) ? 2"
+  )
 })
 
 test_that("unary operators are deparsed", {
@@ -155,29 +299,50 @@ test_that("brackets are deparsed", {
 
 test_that("calls are deparsed", {
   expect_identical(call_deparse(quote(foo(bar, baz))), "foo(bar, baz)")
-  expect_identical(call_deparse(quote(foo(one = bar, two = baz))), "foo(one = bar, two = baz)")
+  expect_identical(
+    call_deparse(quote(foo(one = bar, two = baz))),
+    "foo(one = bar, two = baz)"
+  )
 })
 
 test_that("call_deparse() respects boundaries", {
   ctxt <- new_lines(width = 1L)
-  expect_identical(call_deparse(quote(foo(bar, baz)), ctxt), c("foo(", "  bar,", "  baz)"))
+  expect_identical(
+    call_deparse(quote(foo(bar, baz)), ctxt),
+    c("foo(", "  bar,", "  baz)")
+  )
 
   ctxt <- new_lines(width = 7L)
-  expect_identical(call_deparse(quote(foo(bar, baz)), ctxt), c("foo(", "  bar,", "  baz)"))
+  expect_identical(
+    call_deparse(quote(foo(bar, baz)), ctxt),
+    c("foo(", "  bar,", "  baz)")
+  )
 
   ctxt <- new_lines(width = 8L)
-  expect_identical(call_deparse(quote(foo(bar, baz)), ctxt), c("foo(bar,", "  baz)"))
+  expect_identical(
+    call_deparse(quote(foo(bar, baz)), ctxt),
+    c("foo(bar,", "  baz)")
+  )
 
   ctxt <- new_lines(width = 1L)
-  expect_identical(call_deparse(quote(foo(one = bar, two = baz)), ctxt), c("foo(", "  one = bar,", "  two = baz)"))
+  expect_identical(
+    call_deparse(quote(foo(one = bar, two = baz)), ctxt),
+    c("foo(", "  one = bar,", "  two = baz)")
+  )
 })
 
 test_that("call_deparse() handles multi-line arguments", {
   ctxt <- new_lines(width = 1L)
-  expect_identical(sexp_deparse(quote(foo(one = 1, two = nested(one = 1, two = 2))), ctxt), c("foo(", "  one = 1,", "  two = nested(", "    one = 1,", "    two = 2))"))
+  expect_identical(
+    sexp_deparse(quote(foo(one = 1, two = nested(one = 1, two = 2))), ctxt),
+    c("foo(", "  one = 1,", "  two = nested(", "    one = 1,", "    two = 2))")
+  )
 
   ctxt <- new_lines(width = 20L)
-  expect_identical(sexp_deparse(quote(foo(one = 1, two = nested(one = 1, two = 2))), ctxt), c("foo(one = 1, two = nested(", "  one = 1, two = 2))"))
+  expect_identical(
+    sexp_deparse(quote(foo(one = 1, two = nested(one = 1, two = 2))), ctxt),
+    c("foo(one = 1, two = nested(", "  one = 1, two = 2))")
+  )
 })
 
 test_that("call_deparse() delimits CAR when needed", {
@@ -210,7 +375,10 @@ test_that("call_deparse() delimits CAR when needed", {
 
 test_that("literal functions are deparsed", {
   expect_identical_(sexp_deparse(function(a) 1), "<function(a) 1>")
-  expect_identical_(sexp_deparse(expr(foo(!!function(a) 1))), "foo(<function(a) 1>)")
+  expect_identical_(
+    sexp_deparse(expr(foo(!!function(a) 1))),
+    "foo(<function(a) 1>)"
+  )
 })
 
 test_that("literal dots are deparsed", {
@@ -219,25 +387,49 @@ test_that("literal dots are deparsed", {
 })
 
 test_that("environments are deparsed", {
-  expect_identical(sexp_deparse(expr(foo(!! env()))), "foo(<environment>)")
+  expect_identical(sexp_deparse(expr(foo(!!env()))), "foo(<environment>)")
 })
 
 test_that("atomic vectors are deparsed", {
-  expect_identical(sexp_deparse(set_names(c(TRUE, FALSE, TRUE), c("", "b", ""))), "<lgl: TRUE, b = FALSE, TRUE>")
-  expect_identical(sexp_deparse(set_names(1:3, c("", "b", ""))), "<int: 1L, b = 2L, 3L>")
-  expect_identical(sexp_deparse(set_names(c(1, 2, 3), c("", "b", ""))), "<dbl: 1, b = 2, 3>")
-  expect_identical(sexp_deparse(set_names(as.complex(1:3), c("", "b", ""))), "<cpl: 1+0i, b = 2+0i, 3+0i>")
-  expect_identical(sexp_deparse(set_names(as.character(1:3), c("", "b", ""))), "<chr: \"1\", b = \"2\", \"3\">")
-  expect_identical(sexp_deparse(set_names(as.raw(1:3), c("", "b", ""))), "<raw: 01, b = 02, 03>")
+  expect_identical(
+    sexp_deparse(set_names(c(TRUE, FALSE, TRUE), c("", "b", ""))),
+    "<lgl: TRUE, b = FALSE, TRUE>"
+  )
+  expect_identical(
+    sexp_deparse(set_names(1:3, c("", "b", ""))),
+    "<int: 1L, b = 2L, 3L>"
+  )
+  expect_identical(
+    sexp_deparse(set_names(c(1, 2, 3), c("", "b", ""))),
+    "<dbl: 1, b = 2, 3>"
+  )
+  expect_identical(
+    sexp_deparse(set_names(as.complex(1:3), c("", "b", ""))),
+    "<cpl: 1+0i, b = 2+0i, 3+0i>"
+  )
+  expect_identical(
+    sexp_deparse(set_names(as.character(1:3), c("", "b", ""))),
+    "<chr: \"1\", b = \"2\", \"3\">"
+  )
+  expect_identical(
+    sexp_deparse(set_names(as.raw(1:3), c("", "b", ""))),
+    "<raw: 01, b = 02, 03>"
+  )
 })
 
 test_that("boundaries are respected when deparsing vectors", {
   ctxt <- new_lines(width = 1L)
   vec <- set_names(1:3, c("", "b", ""))
-  expect_identical_(sexp_deparse(expr(foo(!!vec)), ctxt), c("foo(", "  <int:", "    1L,", "    b = 2L,", "    3L>)"))
+  expect_identical_(
+    sexp_deparse(expr(foo(!!vec)), ctxt),
+    c("foo(", "  <int:", "    1L,", "    b = 2L,", "    3L>)")
+  )
 
   ctxt <- new_lines(width = 12L)
-  expect_identical(sexp_deparse(list(c("foo", "bar", "baz")), ctxt), c("<list: <chr:", "  \"foo\",", "  \"bar\",", "  \"baz\">>"))
+  expect_identical(
+    sexp_deparse(list(c("foo", "bar", "baz")), ctxt),
+    c("<list: <chr:", "  \"foo\",", "  \"bar\",", "  \"baz\">>")
+  )
 })
 
 test_that("scalar atomic vectors are simply printed", {
@@ -253,12 +445,18 @@ test_that("scalar raw vectors are printed in long form", {
 })
 
 test_that("literal lists are deparsed", {
-  expect_identical(sexp_deparse(list(TRUE, b = 2L, 3, d = "4", as.raw(5))), "<list: TRUE, b = 2L, 3, d = \"4\", <raw: 05>>")
+  expect_identical(
+    sexp_deparse(list(TRUE, b = 2L, 3, d = "4", as.raw(5))),
+    "<list: TRUE, b = 2L, 3, d = \"4\", <raw: 05>>"
+  )
 })
 
 test_that("long vectors are truncated by default", {
   expect_identical(sexp_deparse(1:10), "<int: 1L, 2L, 3L, 4L, 5L, ...>")
-  expect_identical(sexp_deparse(as.list(1:10)), "<list: 1L, 2L, 3L, 4L, 5L, ...>")
+  expect_identical(
+    sexp_deparse(as.list(1:10)),
+    "<list: 1L, 2L, 3L, 4L, 5L, ...>"
+  )
 })
 
 test_that("long vectors are truncated when max_elements = 0L", {
@@ -271,37 +469,71 @@ test_that("long vectors are truncated when max_elements = 0L", {
 
 test_that("long vectors are not truncated when max_elements = NULL", {
   lines <- new_lines(max_elements = NULL)
-  expect_identical(sexp_deparse(1:10, lines), "<int: 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L>")
+  expect_identical(
+    sexp_deparse(1:10, lines),
+    "<int: 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L>"
+  )
 
   lines <- new_lines(max_elements = NULL)
-  expect_identical(sexp_deparse(as.list(1:10), lines), "<list: 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L>")
+  expect_identical(
+    sexp_deparse(as.list(1:10), lines),
+    "<list: 1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L>"
+  )
 })
 
 test_that("other objects are deparsed with base deparser", {
-  expect_identical_(sexp_deparse(expr(foo((!!base::list)(1, 2)))), "foo(.Primitive(\"list\")(1, 2))")
-  expect_identical_(sexp_deparse(expr(foo((!!base::`if`)(1, 2)))), "foo(.Primitive(\"if\")(1, 2))")
+  expect_identical_(
+    sexp_deparse(expr(foo((!!base::list)(1, 2)))),
+    "foo(.Primitive(\"list\")(1, 2))"
+  )
+  expect_identical_(
+    sexp_deparse(expr(foo((!!base::`if`)(1, 2)))),
+    "foo(.Primitive(\"if\")(1, 2))"
+  )
 })
 
 test_that("S3 objects are deparsed", {
   skip_on_cran()
-  expr <- expr(list(!!factor(1:3), !!structure(list(), class = c("foo", "bar", "baz"))))
+  expr <- expr(list(
+    !!factor(1:3),
+    !!structure(list(), class = c("foo", "bar", "baz"))
+  ))
   expect_identical(sexp_deparse(expr), "list(<fct>, <foo>)")
 })
 
 test_that("successive indentations on a single line are only counted once", {
   ctxt <- new_lines(5L)
-  broken_output <- c("<list:", "  <chr:", "    foo = \"bar\",", "    baz = \"bam\">>")
-  expect_identical(sexp_deparse(list(c(foo = "bar", baz = "bam")), ctxt), broken_output)
+  broken_output <- c(
+    "<list:",
+    "  <chr:",
+    "    foo = \"bar\",",
+    "    baz = \"bam\">>"
+  )
+  expect_identical(
+    sexp_deparse(list(c(foo = "bar", baz = "bam")), ctxt),
+    broken_output
+  )
 
   ctxt <- new_lines(12L)
   unbroken_output <- c("<list: <chr:", "  foo = \"bar\",", "  baz = \"bam\">>")
-  expect_identical(sexp_deparse(list(c(foo = "bar", baz = "bam")), ctxt), unbroken_output)
+  expect_identical(
+    sexp_deparse(list(c(foo = "bar", baz = "bam")), ctxt),
+    unbroken_output
+  )
 })
 
 test_that("successive indentations close off properly", {
   expect_identical(sexp_deparse(quote(1(2(), 3(4())))), "1(2(), 3(4()))")
-  expect_identical(sexp_deparse(quote(1(2(), 3(4()))), new_lines(width = 1L)), c("1(", "  2(),", "  3(", "    4()))"))
-  expect_identical(sexp_deparse(expr(c((1), function() { 2 }))), c("c((1), function() {", "  2", "})"))
+  expect_identical(
+    sexp_deparse(quote(1(2(), 3(4()))), new_lines(width = 1L)),
+    c("1(", "  2(),", "  3(", "    4()))")
+  )
+  expect_identical(
+    sexp_deparse(expr(c((1), function() {
+      2
+    }))),
+    c("c((1), function() {", "  2", "})")
+  )
 })
 
 test_that("empty quosures are deparsed", {
@@ -326,7 +558,10 @@ test_that("missing values are deparsed", {
   expect_identical(sexp_deparse(quote(call(NA_integer_))), "call(NA_integer_)")
   expect_identical(sexp_deparse(quote(call(NA_real_))), "call(NA_real_)")
   expect_identical(sexp_deparse(quote(call(NA_complex_))), "call(NA_complex_)")
-  expect_identical(sexp_deparse(quote(call(NA_character_))), "call(NA_character_)")
+  expect_identical(
+    sexp_deparse(quote(call(NA_character_))),
+    "call(NA_character_)"
+  )
 })
 
 test_that("needs_backticks() detects non-syntactic symbols", {
@@ -336,9 +571,15 @@ test_that("needs_backticks() detects non-syntactic symbols", {
 
   expect_true(all(map_lgl(c("1", ".1", "~", "!"), needs_backticks)))
   expect_true(all(map_lgl(c("_", "_foo", "1foo"), needs_backticks)))
-  expect_true(all(map_lgl(c(".fo!o", "b&ar", "baz <- _baz", "~quux.", "h~unoz_"), needs_backticks)))
+  expect_true(all(map_lgl(
+    c(".fo!o", "b&ar", "baz <- _baz", "~quux.", "h~unoz_"),
+    needs_backticks
+  )))
 
-  expect_false(any(map_lgl(c(".foo", "._1", "bar", "baz_baz", "quux.", "hunoz_", "..."), needs_backticks)))
+  expect_false(any(map_lgl(
+    c(".foo", "._1", "bar", "baz_baz", "quux.", "hunoz_", "..."),
+    needs_backticks
+  )))
 
   expect_false(needs_backticks(expr()))
 })
@@ -364,7 +605,7 @@ test_that("expr_text() deparses empty arguments", {
 test_that("expr_name() deparses empty arguments", {
   expect_identical(expr_name(expr()), "")
   expect_identical(quo_name(quo()), "")
-  expect_identical(names(quos_auto_name(quos(, ))), "<empty>")
+  expect_identical(names(quos_auto_name(quos(,))), "<empty>")
   expect_identical(as_label(expr()), "<empty>")
 })
 
@@ -413,10 +654,16 @@ test_that("as_label() handles objects", {
 
 test_that("bracket deparsing is a form of argument deparsing", {
   expect_identical(expr_deparse(quote(foo[bar, , baz()])), "foo[bar, , baz()]")
-  expect_identical(expr_deparse(quote(foo[[bar, , baz()]])), "foo[[bar, , baz()]]")
+  expect_identical(
+    expr_deparse(quote(foo[[bar, , baz()]])),
+    "foo[[bar, , baz()]]"
+  )
 
   skip_on_cran()
-  expect_identical(expr_deparse(call("[", iris, missing_arg(), drop = FALSE)), "<df[,5]>[, drop = FALSE]")
+  expect_identical(
+    expr_deparse(call("[", iris, missing_arg(), drop = FALSE)),
+    "<df[,5]>[, drop = FALSE]"
+  )
 })
 
 test_that("non-syntactic symbols are deparsed with backticks", {
@@ -436,16 +683,28 @@ test_that("symbols with unicode are deparsed consistently (#691)", {
 })
 
 test_that("formal parameters are backticked if needed", {
-  expect_identical(expr_deparse(function(`^`) {}), c("<function(`^`) { }>"))
+  expect_identical(
+    expr_deparse(function(`^`) {
+    }),
+    c("<function(`^`) { }>")
+  )
 })
 
 test_that("empty blocks are deparsed on the same line", {
-  expect_identical(expr_deparse(quote({ })), "{ }")
+  expect_identical(
+    expr_deparse(quote({
+    })),
+    "{ }"
+  )
 })
 
 test_that("top-level S3 objects are deparsed", {
   skip_on_cran()
-  f <- structure(function() { }, class = "lambda")
+  f <- structure(
+    function() {
+    },
+    class = "lambda"
+  )
   expect_identical(expr_deparse(f), "<lambda>")
 })
 
@@ -464,7 +723,13 @@ test_that("as_label() supports symbols, calls, and literals", {
   expect_identical(as_label(1L), "1L")
   expect_identical(as_label("foo"), "\"foo\"")
   expect_identical(as_label(function() NULL), "<fn>")
-  expect_identical(as_label(expr(function() { a; b })), "function() ...")
+  expect_identical(
+    as_label(expr(function() {
+      a
+      b
+    })),
+    "function() ..."
+  )
   expect_identical(as_label(1:2), "<int>")
   expect_identical(as_label(env()), "<env>")
 })
@@ -478,18 +743,24 @@ test_that("as_label() supports special objects", {
 })
 
 test_that("as_name() supports quosured symbols and strings", {
-   expect_identical(as_name(quo(foo)), "foo")
-   expect_identical(as_name(quo("foo")), "foo")
-   expect_error(as_name(quo(foo())), "Can't convert a call to a string")
- })
+  expect_identical(as_name(quo(foo)), "foo")
+  expect_identical(as_name(quo("foo")), "foo")
+  expect_error(as_name(quo(foo())), "Can't convert a call to a string")
+})
 
 test_that("named empty lists are marked as named", {
   expect_identical(expr_deparse(set_names(list(), chr())), "<named list>")
 })
 
 test_that("infix operators are sticky", {
-  expect_identical(expr_deparse(quote(foo %>% bar), width = 3L), c("foo %>%", "  bar"))
-  expect_identical(expr_deparse(quote(foo + bar), width = 3L), c("foo +", "  bar"))
+  expect_identical(
+    expr_deparse(quote(foo %>% bar), width = 3L),
+    c("foo %>%", "  bar")
+  )
+  expect_identical(
+    expr_deparse(quote(foo + bar), width = 3L),
+    c("foo +", "  bar")
+  )
 })
 
 test_that("argument names are backticked if needed (#950)", {
@@ -497,7 +768,13 @@ test_that("argument names are backticked if needed (#950)", {
 })
 
 test_that("`next` and `break` are deparsed", {
-  expect_equal(expr_deparse(quote({ next; (break) })), c("{", "  next",  "  (break)", "}"))
+  expect_equal(
+    expr_deparse(quote({
+      next
+      (break)
+    })),
+    c("{", "  next", "  (break)", "}")
+  )
   expect_equal(expr_deparse(quote(a <- next <- break)), c("a <- next <- break"))
 })
 
@@ -581,11 +858,11 @@ test_that("formulas are deparsed (#1169)", {
 
   # Unevaluated formulas with expressions have a space
   expect_equal(
-    expr_deparse(quote(~+foo)),
+    expr_deparse(quote(~ +foo)),
     "~ +foo"
   )
   expect_equal(
-    expr_deparse(quote(~foo())),
+    expr_deparse(quote(~ foo())),
     "~ foo()"
   )
 })
@@ -606,7 +883,13 @@ test_that("matrices and arrays are formatted (#383)", {
 
 test_that("infix operators are labelled (#956, r-lib/testthat#1432)", {
   expect_equal(
-    as_label(quote({ 1; 2} + 3)),
+    as_label(quote(
+      {
+        1
+        2
+      } +
+        3
+    )),
     "... + 3"
   )
 
@@ -623,7 +906,10 @@ test_that("infix operators are labelled (#956, r-lib/testthat#1432)", {
   )
 
   expect_equal(
-    as_label(quote(X[key1 == "val1" & key2 == "val2"]$key3 & foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz())))))))),
+    as_label(quote(
+      X[key1 == "val1" & key2 == "val2"]$key3 &
+        foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz(foobarbaz()))))))
+    )),
     "X[key1 == \"val1\" & key2 == \"val2\"]$key3 & ..."
   )
 
@@ -641,8 +927,9 @@ test_that("infix operators are labelled (#956, r-lib/testthat#1432)", {
   # This fits into 60 characters if we truncate either side,
   # so we don't need to shorten both of them
   expect_equal(
-    as_label(quote(very_long_expression[with(subsetting), -1] -
-                     another_very_long_expression[with(subsetting), -1]
+    as_label(quote(
+      very_long_expression[with(subsetting), -1] -
+        another_very_long_expression[with(subsetting), -1]
     )),
     "very_long_expression[with(subsetting), -1] - ..."
   )
@@ -694,15 +981,18 @@ test_that("binary op without arguments", {
 })
 
 test_that("call_deparse_highlight() handles long lists of arguments (#1456)", {
-  out <- call_deparse_highlight(quote(
-    foo(
-      aaaaaa = aaaaaa,
-      bbbbbb = bbbbbb,
-      cccccc = cccccc,
-      dddddd = dddddd,
-      eeeeee = eeeeee
-    )
-  ), NULL)
+  out <- call_deparse_highlight(
+    quote(
+      foo(
+        aaaaaa = aaaaaa,
+        bbbbbb = bbbbbb,
+        cccccc = cccccc,
+        dddddd = dddddd,
+        eeeeee = eeeeee
+      )
+    ),
+    NULL
+  )
 
   expect_equal(
     cli::ansi_strip(out),
@@ -711,12 +1001,15 @@ test_that("call_deparse_highlight() handles long lists of arguments (#1456)", {
 })
 
 test_that("call_deparse_highlight() handles multi-line arguments (#1456)", {
-  out <- call_deparse_highlight(quote(
-    fn(arg = {
-      a
-      b
-    })
-  ), NULL)
+  out <- call_deparse_highlight(
+    quote(
+      fn(arg = {
+        a
+        b
+      })
+    ),
+    NULL
+  )
 
   expect_equal(
     cli::ansi_strip(out),
