@@ -30,7 +30,10 @@ test_that("env_poke() creates binding if `create` is TRUE", {
   env_poke(env, "foo", "foo")
   expect_identical(env_get(env, "foo"), "foo")
 
-  expect_error(env_poke(env, "bar", "BAR", create = FALSE), "Can't find existing binding")
+  expect_error(
+    env_poke(env, "bar", "BAR", create = FALSE),
+    "Can't find existing binding"
+  )
   env_poke(env, "foo", "FOO", create = FALSE)
   expect_identical(env_get(env, "foo"), "FOO")
 })
@@ -45,8 +48,14 @@ test_that("env_poke() inherits from parents if `inherit` is TRUE", {
   env_poke(env, "foo", "FOO", inherit = TRUE, create = FALSE)
   expect_identical(env_get(env_parent(env), "foo", inherit = FALSE), "FOO")
 
-  expect_error(env_poke(env, "bar", "bar", inherit = TRUE, create = FALSE), "Can't find existing binding")
-  expect_error(env_poke(env, "bar", "bar", inherit = TRUE), "Can't find existing binding")
+  expect_error(
+    env_poke(env, "bar", "bar", inherit = TRUE, create = FALSE),
+    "Can't find existing binding"
+  )
+  expect_error(
+    env_poke(env, "bar", "bar", inherit = TRUE),
+    "Can't find existing binding"
+  )
 
   env_poke(env, "bar", "bar", inherit = TRUE, create = TRUE)
   expect_identical(env_get(env, "bar"), "bar")
@@ -63,22 +72,21 @@ test_that("env_get() evaluates promises and active bindings", {
 
 test_that("env_get_list() retrieves multiple bindings", {
   env <- env(foo = 1L, bar = 2L)
-  expect_identical(env_get_list(env, c("foo", "bar")), list(foo = 1L, bar =2L))
+  expect_identical(env_get_list(env, c("foo", "bar")), list(foo = 1L, bar = 2L))
 
   baz <- 0L
   expect_error(env_get_list(env, "baz"), "Can't find")
-  expect_identical(env_get_list(env, c("foo", "baz"), inherit = TRUE), list(foo = 1L, baz =0L))
+  expect_identical(
+    env_get_list(env, c("foo", "baz"), inherit = TRUE),
+    list(foo = 1L, baz = 0L)
+  )
 })
 
 test_that("local_bindings binds temporarily", {
   env <- env(foo = "foo", bar = "bar")
 
   local({
-    old <- local_bindings(.env = env,
-      foo = "FOO",
-      bar = "BAR",
-      baz = "BAZ"
-    )
+    old <- local_bindings(.env = env, foo = "FOO", bar = "BAR", baz = "BAZ")
     expect_identical(old, list3(foo = "foo", bar = "bar", baz = zap()))
     temp_bindings <- env_get_list(env, c("foo", "bar", "baz"))
     expect_identical(temp_bindings, list(foo = "FOO", bar = "BAR", baz = "BAZ"))
@@ -135,7 +143,10 @@ test_that("env_names() unserialises unicode", {
 })
 
 test_that("env_has() returns a named vector", {
-  expect_identical(env_has(env(a = TRUE), c("a", "b", "c")), c(a = TRUE, b = FALSE, c = FALSE))
+  expect_identical(
+    env_has(env(a = TRUE), c("a", "b", "c")),
+    c(a = TRUE, b = FALSE, c = FALSE)
+  )
 })
 
 test_that("env_unbind() doesn't warn if binding doesn't exist (#177)", {
@@ -149,13 +160,16 @@ test_that("env_get() and env_get_list() accept default value", {
   expect_error(env_get_list(env, "b"), "Can't find")
 
   expect_identical(env_get(env, "b", default = "foo"), "foo")
-  expect_identical(env_get_list(env, c("a", "b"), default = "foo"), list(a = 1, b = "foo"))
+  expect_identical(
+    env_get_list(env, c("a", "b"), default = "foo"),
+    list(a = 1, b = "foo")
+  )
 })
 
 test_that("env_get() without default fails", {
-  expect_snapshot({
-    (expect_error(env_get(env(), "foobar")))
-    (expect_error(env_get_list(env(), "foobar")))
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
+    env_get(env(), "foobar")
+    env_get_list(env(), "foobar")
   })
 
   fn <- function(env, default) env_get(env, "_foobar", default = default)
@@ -167,7 +181,7 @@ test_that("env_get() evaluates `default` lazily", {
 })
 
 test_that("env_bind_active() uses as_function()", {
-  env_bind_active(current_env(), foo = ~2 + 3)
+  env_bind_active(current_env(), foo = ~ 2 + 3)
   expect_identical(foo, 5)
 })
 
@@ -180,15 +194,24 @@ test_that("env_bind_active() and env_bind_lazy() redefine bindings", {
 
 test_that("binding predicates detect special bindings", {
   env <- env()
-  env_bind_active(env, a = ~toupper("foo"))
+  env_bind_active(env, a = ~ toupper("foo"))
   env_bind_lazy(env, b = toupper("foo"))
   env_bind(env, c = toupper("foo"), d = "irrelevant")
 
-  expect_identical(env_binding_are_active(env, c("a", "b", "c")), c(a = TRUE, b = FALSE, c = FALSE))
-  expect_identical(env_binding_are_lazy(env, c("a", "b", "c")), c(a = FALSE, b = TRUE, c = FALSE))
+  expect_identical(
+    env_binding_are_active(env, c("a", "b", "c")),
+    c(a = TRUE, b = FALSE, c = FALSE)
+  )
+  expect_identical(
+    env_binding_are_lazy(env, c("a", "b", "c")),
+    c(a = FALSE, b = TRUE, c = FALSE)
+  )
 
   force(env$b)
-  expect_identical(env_binding_are_lazy(env, c("a", "b", "c")), c(a = FALSE, b = FALSE, c = FALSE))
+  expect_identical(
+    env_binding_are_lazy(env, c("a", "b", "c")),
+    c(a = FALSE, b = FALSE, c = FALSE)
+  )
 
   env <- env(a = 1, b = 2)
   expect_identical(env_binding_are_active(env), c(a = FALSE, b = FALSE))
@@ -197,10 +220,13 @@ test_that("binding predicates detect special bindings", {
 
 test_that("applies predicates to all bindings by default", {
   env <- env()
-  env_bind_active(env, a = ~toupper("foo"))
+  env_bind_active(env, a = ~ toupper("foo"))
   env_bind_lazy(env, b = toupper("foo"))
   env_bind(env, c = toupper("foo"))
-  expect_identical(env_binding_are_active(env), c(a = TRUE, b = FALSE, c = FALSE))
+  expect_identical(
+    env_binding_are_active(env),
+    c(a = TRUE, b = FALSE, c = FALSE)
+  )
   expect_identical(env_binding_are_lazy(env), c(a = FALSE, b = TRUE, c = FALSE))
 })
 
@@ -214,7 +240,7 @@ test_that("env_binding_are_active() doesn't force promises", {
 
 test_that("env_binding_are_active() doesn't trigger active bindings (#1376)", {
   env <- env()
-  env_bind_active(env, foo = ~stop("kaboom"))
+  env_bind_active(env, foo = ~ stop("kaboom"))
   expect_no_error(env_binding_are_active(env))
   expect_identical(env_binding_are_active(env), lgl(foo = TRUE))
   expect_identical(env_binding_are_lazy(env), lgl(foo = FALSE))
@@ -224,11 +250,7 @@ test_that("env_binding_type_sum() detects types", {
   env <- env()
   env_bind_active(env, a = ~"foo")
   env_bind_lazy(env, b = identity("foo"))
-  env_bind(env,
-    c = "foo",
-    d = 1L,
-    e = 2
-  )
+  env_bind(env, c = "foo", d = 1L, e = 2)
 
   expect_error(env_binding_type_sum(env, 1L), "must be a character vector")
 
@@ -329,7 +351,10 @@ test_that("env_bind_lazy() supports nested quosures", {
 
   quo <- local({
     lhs <- "quux"
-    rhs <- local({ rhs <- "hunoz"; quo(rhs) })
+    rhs <- local({
+      rhs <- "hunoz"
+      quo(rhs)
+    })
     quo(paste(lhs, !!rhs))
   })
 
@@ -342,7 +367,10 @@ test_that("env_bind_active() supports nested quosures", {
 
   quo <- local({
     lhs <- "quux"
-    rhs <- local({ rhs <- "hunoz"; quo(rhs) })
+    rhs <- local({
+      rhs <- "hunoz"
+      quo(rhs)
+    })
     quo(paste(lhs, !!rhs))
   })
 
@@ -389,12 +417,17 @@ test_that("env_poke() zaps (#1012)", {
 })
 
 test_that("env_poke() doesn't warn when unrepresentable characters are serialised", {
+  if (is_windows && getRversion() < "4.2") {
+    return()
+  }
+
   with_non_utf8_locale({
     e <- env(empty_env())
     nm <- get_alien_lang_string()
 
     expect_no_warning(env_poke(e, nm, NA))
 
+    skip_if_no_utf8_marker()
     nms <- env_names(e)
     expect_equal(Encoding(nms), "UTF-8")
   })
@@ -451,23 +484,23 @@ test_that("env_get() and env_get_list() handle `last` argument", {
 })
 
 test_that("env_cache() works (#1081)", {
- e <- env(a = "foo")
+  e <- env(a = "foo")
 
- # Returns existing binding
- expect_equal(
-   env_cache(e, "a", "default"),
-   "foo"
- )
+  # Returns existing binding
+  expect_equal(
+    env_cache(e, "a", "default"),
+    "foo"
+  )
 
- # Creates a `b` binding and returns its default value
- expect_equal(
-   env_cache(e, "b", "default"),
-   "default"
- )
+  # Creates a `b` binding and returns its default value
+  expect_equal(
+    env_cache(e, "b", "default"),
+    "default"
+  )
 
- # Now `b` is defined
- expect_equal(e$b, "default")
- expect_equal(e$a, "foo")
+  # Now `b` is defined
+  expect_equal(e$b, "default")
+  expect_equal(e$a, "foo")
 })
 
 test_that("env_get(last = ) checks for empty env when last is disconnected (#1208)", {
