@@ -8,9 +8,12 @@ test_that("always returns single string", {
 })
 
 test_that("can truncate lines", {
-  out <- expr_text(quote({
-    a + b
-  }), nlines = 2)
+  out <- expr_text(
+    quote({
+      a + b
+    }),
+    nlines = 2
+  )
   expect_equal(out, "{\n...")
 })
 
@@ -31,8 +34,19 @@ test_that("converts atomics to strings", {
 })
 
 test_that("expr_label() truncates blocks", {
-  expect_identical(expr_label(quote({ a + b })), "`{ ... }`")
-  expect_identical(expr_label(expr(function() { a; b })), "`function() ...`")
+  expect_identical(
+    expr_label(quote({
+      a + b
+    })),
+    "`{ ... }`"
+  )
+  expect_identical(
+    expr_label(expr(function() {
+      a
+      b
+    })),
+    "`function() ...`"
+  )
 })
 
 test_that("expr_label() truncates long calls", {
@@ -42,6 +56,9 @@ test_that("expr_label() truncates long calls", {
   expect_identical(expr_label(long_call), "`foo(...)`")
 })
 
+test_that("expr_label() NULL values come out as expected", {
+  expect_identical(expr_label(NULL), "NULL")
+})
 
 # expr_name() --------------------------------------------------------
 
@@ -51,10 +68,16 @@ test_that("expr_name() with symbols, calls, and literals", {
   expect_identical(expr_name(1L), "1")
   expect_identical(expr_name("foo"), "foo")
   expect_identical(expr_name(function() NULL), "function () ...")
-  expect_identical(expr_name(expr(function() { a; b })), "function() ...")
+  expect_identical(
+    expr_name(expr(function() {
+      a
+      b
+    })),
+    "function() ..."
+  )
   expect_identical(expr_name(NULL), "NULL")
-  expect_error(expr_name(1:2), "must quote")
-  expect_error(expr_name(env()), "must quote")
+  expect_error(expr_name(1:2), "must be")
+  expect_error(expr_name(env()), "must be")
 })
 
 # --------------------------------------------------------------------
@@ -80,3 +103,30 @@ test_that("imaginary numbers with real part are not syntactic", {
   expect_true(is_syntactic_literal(na_cpl))
   expect_false(is_syntactic_literal(1 + 1i))
 })
+
+test_that("is_expression() detects non-parsable parse trees", {
+  expect_true(is_expression(quote(foo(bar = baz(1, NULL)))))
+  expect_false(is_expression(expr(foo(bar = baz(!!(1:2), NULL)))))
+  expect_false(is_expression(call2(identity)))
+})
+
+test_that("is_expression() supports missing arguments", {
+  expect_false(is_expression(missing_arg()))
+  expect_false(is_expression(quote(foo(,))))
+})
+
+test_that("is_expression() supports quoted functions (#1499)", {
+  expect_true(is_expression(parse_expr("function() NULL")))
+})
+
+test_that("is_expression() detects attributes (#1475)", {
+  x <- structure(quote(foo()), attr = TRUE)
+  expect_false(is_expression(x))
+  expect_false(is_expression(expr(call(!!x))))
+  expect_true(is_expression(quote({
+    NULL
+  })))
+  expect_true(is_expression(quote(function() {
+    NULL
+  })))
+})
